==> haskell-smallcheck-1.1.4-3-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-smallcheck.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: smallcheck
version: 1.1.4
id: smallcheck-1.1.4-CnGyVRrYv24DCDBukmNZV6
key: smallcheck-1.1.4-CnGyVRrYv24DCDBukmNZV6
license: BSD-3-Clause
maintainer: Roman Cheplyaka <roma@ro-che.info>
author: Colin Runciman, Roman Cheplyaka
stability: Beta
homepage: https://github.com/feuerbach/smallcheck
synopsis: A property-based testing library
description:
    SmallCheck is a testing library that allows to verify properties
    for all test cases up to some depth. The test cases are generated
    automatically by SmallCheck.
category: Testing
abi: 1d196b8004c7b0f0d9a17647f655ad90
exposed: True
exposed-modules:
    Test.SmallCheck Test.SmallCheck.Drivers Test.SmallCheck.Series
hidden-modules: Test.SmallCheck.Property
                Test.SmallCheck.SeriesMonad Test.SmallCheck.Property.Result
import-dirs: /usr/lib/ghc-8.4.3/site-local/smallcheck-1.1.4
library-dirs: /usr/lib/ghc-8.4.3/site-local/smallcheck-1.1.4
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/smallcheck-1.1.4
hs-libraries: HSsmallcheck-1.1.4-CnGyVRrYv24DCDBukmNZV6
depends:
    base-4.11.1.0 ghc-prim-0.5.2.0 logict-0.6.0.2-bTigcTuAfUFUMwCRYsf8L
    mtl-2.2.2 pretty-1.1.3.6
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             ghc-prim-0.5.2.0=387aa7e78e4e6c49e51798e4d6763c3f
             logict-0.6.0.2-bTigcTuAfUFUMwCRYsf8L=93a38d7204a51c002db7c04ebda479ff
             mtl-2.2.2=0b3b35c3b96c7607606ed10087c4aa4a
             pretty-1.1.3.6=3c31686bd534e1773b954ae82713db97
haddock-interfaces: /usr/share/doc/haskell-smallcheck/html/smallcheck.haddock
haddock-html: /usr/share/doc/haskell-smallcheck/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-smallcheck-1.1.5-1-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-smallcheck.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: smallcheck
version: 1.1.5
id: smallcheck-1.1.5-3f5qiJxrEExLmWHgkqVfWS
key: smallcheck-1.1.5-3f5qiJxrEExLmWHgkqVfWS
license: BSD-3-Clause
maintainer: Roman Cheplyaka <roma@ro-che.info>
author: Colin Runciman, Roman Cheplyaka
stability: Beta
homepage: https://github.com/feuerbach/smallcheck
synopsis: A property-based testing library
description:
    SmallCheck is a testing library that allows to verify properties
    for all test cases up to some depth. The test cases are generated
    automatically by SmallCheck.
category: Testing
abi: aec4190e63046da29e6cea1cb38a365c
exposed: True
exposed-modules:
    Test.SmallCheck Test.SmallCheck.Drivers Test.SmallCheck.Series
hidden-modules: Test.SmallCheck.Property
                Test.SmallCheck.SeriesMonad Test.SmallCheck.Property.Result
import-dirs: /usr/lib/ghc-8.4.3/site-local/smallcheck-1.1.5
library-dirs: /usr/lib/ghc-8.4.3/site-local/smallcheck-1.1.5
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/smallcheck-1.1.5
hs-libraries: HSsmallcheck-1.1.5-3f5qiJxrEExLmWHgkqVfWS
depends:
    base-4.11.1.0 ghc-prim-0.5.2.0 logict-0.6.0.2-bTigcTuAfUFUMwCRYsf8L
    mtl-2.2.2 pretty-1.1.3.6
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             ghc-prim-0.5.2.0=387aa7e78e4e6c49e51798e4d6763c3f
             logict-0.6.0.2-bTigcTuAfUFUMwCRYsf8L=93a38d7204a51c002db7c04ebda479ff
             mtl-2.2.2=0b3b35c3b96c7607606ed10087c4aa4a
             pretty-1.1.3.6=3c31686bd534e1773b954ae82713db97
haddock-interfaces: /usr/share/doc/haskell-smallcheck/html/smallcheck.haddock
haddock-html: /usr/share/doc/haskell-smallcheck/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
